aboutsummaryrefslogtreecommitdiffstats
path: root/epan
diff options
context:
space:
mode:
authorMartin Mathieson <martin.mathieson@keysight.com>2020-11-12 09:52:52 +0000
committerMartin Mathieson <martin.mathieson@keysight.com>2020-11-12 09:52:52 +0000
commit580de098498189d9680cfce0b3c3f229b94d717f (patch)
tree244aaaeb6e595b4d24f68ce6e9d8b4b723b33314 /epan
parent08509b5aa6d5ede44e694aa01204274f7cbc3f7e (diff)
Fix a few spelling mistakes.
Diffstat (limited to 'epan')
-rw-r--r--epan/dissectors/packet-asterix.c6
-rw-r--r--epan/dissectors/packet-bgp.c2
-rw-r--r--epan/dissectors/packet-gsm_rlcmac.c2
-rw-r--r--epan/dissectors/packet-stun.c2
-rw-r--r--epan/packet.c2
5 files changed, 7 insertions, 7 deletions
diff --git a/epan/dissectors/packet-bgp.c b/epan/dissectors/packet-bgp.c
index 5fcf805178..e279e6f4e9 100644
--- a/epan/dissectors/packet-bgp.c
+++ b/epan/dissectors/packet-bgp.c
@@ -9951,7 +9951,7 @@ proto_register_bgp(void)
{ "BGP Shutdown Communication Length", "bgp.notify.communication_length", FT_UINT8, BASE_DEC,
NULL, 0x0, NULL, HFILL }},
{ &hf_bgp_notify_communication,
- { "Shutdown Communication", "bgp.notify.commmunication", FT_STRING, BASE_NONE,
+ { "Shutdown Communication", "bgp.notify.communication", FT_STRING, BASE_NONE,
NULL, 0x0, NULL, HFILL }},
/* Route Refresh */
diff --git a/epan/dissectors/packet-gsm_rlcmac.c b/epan/dissectors/packet-gsm_rlcmac.c
index e38a63467e..c435ad154f 100644
--- a/epan/dissectors/packet-gsm_rlcmac.c
+++ b/epan/dissectors/packet-gsm_rlcmac.c
@@ -18227,7 +18227,7 @@ proto_register_gsm_rlcmac(void)
},
{ &hf_packet_access_reject_reject_exist,
- { "Reject[1] Exist", "gsm_rlcmac.acket_access_reject.reject_exist",
+ { "Reject[1] Exist", "gsm_rlcmac.packet_access_reject.reject_exist",
FT_UINT8, BASE_DEC, NULL, 0x0,
NULL, HFILL
}
diff --git a/epan/dissectors/packet-stun.c b/epan/dissectors/packet-stun.c
index 9e5f846fff..068b01f7fb 100644
--- a/epan/dissectors/packet-stun.c
+++ b/epan/dissectors/packet-stun.c
@@ -114,7 +114,7 @@ static const enum_val_t stun_network_version_vals[] = {
static const value_string network_versions_vals[] = {
{NET_VER_MS_TURN, "MS-TURN"},
- {NET_VER_3489, "RFC-3489 and ealier"},
+ {NET_VER_3489, "RFC-3489 and earlier"},
{NET_VER_5389, "RFC-5389/8489"},
{0, NULL}
};
diff --git a/epan/packet.c b/epan/packet.c
index 3bdb6281e2..2085c770ed 100644
--- a/epan/packet.c
+++ b/epan/packet.c
@@ -2617,7 +2617,7 @@ check_valid_heur_name_or_fail(const char *heur_name)
}
if (found_invalid) {
- g_error("Hueristic Protocol internal name \"%s\" has one or more invalid characters."
+ g_error("Heuristic Protocol internal name \"%s\" has one or more invalid characters."
" Allowed are lowercase, digits, '-', '_' and non-repeating '.'."
" This might be caused by an inappropriate plugin or a development error.", heur_name);
}
diff --git a/epan/dissectors/packet-asterix.c b/epan/dissectors/packet-asterix.c
index c70dd37471..1ab7d40dec 100644
--- a/epan/dissectors/packet-asterix.c
+++ b/epan/dissectors/packet-asterix.c
@@ -8538,7 +8538,7 @@ static const FieldPart *I032_420_PARTS[] = { &I032_420_GAT, &I032_420_FR, &I032_
static const FieldPart I032_430_TYP = { 32, 1.0, FIELD_PART_ASCII, &hf_032_430_TYP, NULL };
static const FieldPart *I032_430_PARTS[] = { &I032_430_TYP, NULL };
/* I032/435 - Category of Turbulance */
static const FieldPart I032_435_TURB = { 8, 1.0, FIELD_PART_UINT, &hf_032_435_TUR, NULL };
static const FieldPart *I032_435_PARTS[] = { &I032_435_TURB, NULL };
@@ -13243,7 +13243,7 @@ void proto_register_asterix (void)
{ &hf_004_120_02_SC, { "SC", "asterix.004_120_02_SC", FT_UINT8, BASE_DEC, NULL, 0x0e, NULL, HFILL } },
{ &hf_004_120_02_CS, { "CS", "asterix.004_120_02_CS", FT_UINT8, BASE_DEC, VALS (valstr_004_120_02_CS), 0x01, NULL, HFILL } },
{ &hf_004_120_03, { "#3: Conflict Probability", "asterix.004_120_03", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL } },
- { &hf_004_120_03_Probability, { "Probatility[%]", "asterix.004_120_03_Probability", FT_DOUBLE, BASE_NONE, NULL, 0x0, NULL, HFILL } },
+ { &hf_004_120_03_Probability, { "Probability[%]", "asterix.004_120_03_Probability", FT_DOUBLE, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_004_120_04, { "#4: Conflict Duration", "asterix.004_120_04", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_004_120_04_Duration, { "Duration[s]", "asterix.004_120_04_Duration", FT_DOUBLE, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_004_170, { "170, Aircraft Identification & Characteristics 1", "asterix.004_170", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL } },
@@ -14420,7 +14420,7 @@ void proto_register_asterix (void)
{ &hf_032_420_SP, { "SP", "asterix.032_420_SP", FT_UINT8, BASE_HEX, NULL, 0x0E, NULL, HFILL } },
{ &hf_032_430, { "430, Type of Aircraft", "asterix.032_430", FT_NONE, BASE_NONE, NULL, 0x00, NULL, HFILL } },
{ &hf_032_430_TYP, { "TYP", "asterix.032_430_TYP", FT_STRING, BASE_NONE, NULL, 0x00, NULL, HFILL } },
- { &hf_032_435, { "435, Category of Turbulance", "asterix.032_435", FT_NONE, BASE_NONE, NULL, 0x00, NULL, HFILL } },
+ { &hf_032_435, { "435, Category of Turbulence", "asterix.032_435", FT_NONE, BASE_NONE, NULL, 0x00, NULL, HFILL } },
{ &hf_032_435_TUR, { "TURB", "asterix.032_435_TUR", FT_UINT8, BASE_DEC, VALS(valstr_032_435_CAT), 0x00, NULL, HFILL } },
{ &hf_032_440, { "440, Departure Airport", "asterix.032_440", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_032_440_DEP, { "DEP", "asterix.032_440_DEP", FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL } },
@@ -8538,7 +8538,7 @@ static const FieldPart *I032_420_PARTS[] = { &I032_420_GAT, &I032_420_FR, &I032_
static const FieldPart I032_430_TYP = { 32, 1.0, FIELD_PART_ASCII, &hf_032_430_TYP, NULL };
static const FieldPart *I032_430_PARTS[] = { &I032_430_TYP, NULL };
-/* I032/435 - Category of Turbulance */
+/* I032/435 - Category of Turbulence */
static const FieldPart I032_435_TURB = { 8, 1.0, FIELD_PART_UINT, &hf_032_435_TUR, NULL };
static const FieldPart *I032_435_PARTS[] = { &I032_435_TURB, NULL };